@@ -1304,7 +1304,7 @@ get_bool_reply_for_header (FlatpakProxyClient *client, Header *header, gboolean
   g_dbus_message_set_message_type (reply, G_DBUS_MESSAGE_TYPE_METHOD_RETURN);
   g_dbus_message_set_flags (reply, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
   g_dbus_message_set_reply_serial (reply, header->serial - client->serial_offset);
-  g_dbus_message_set_body (reply, g_variant_new_boolean (val));
+  g_dbus_message_set_body (reply, g_variant_new ("(b)", val));
 
   return reply;
 }
